ItemDeliveryPromise : Promised delivery information for the item.
Fields
start_time: Option<String>The date and time of the start of the promised delivery window in ISO 8601 format.
end_time: Option<String>The date and time of the end of the promised delivery window in ISO 8601 format.
Implementations
sourceimpl ItemDeliveryPromise
impl ItemDeliveryPromise
sourcepub fn new() -> ItemDeliveryPromise
pub fn new() -> ItemDeliveryPromise
Promised delivery information for the item.